@@ -9,15 +9,6 @@ from .judi_responder import JudiResponder
 from .console_device import ConsoleDevice
 from .unknown_device import UnknownDevice, DeviceStates
 
-try:
-    from plugins.devices import *
-except:
-    pass
-
-profiles = {p.profile_name: p for p in SerialDevice.__subclasses__()}
-
-profile_names = sorted(profiles.keys())
-
 from .device_manager import DeviceManager
 from .subscriptions import SubscriptionManager
 from .device_controls import DeviceControlsWidget, DeviceControlsDockWidget
\ No newline at end of file
